package edu.prlab.ecsimple.service;

import edu.prlab.ecsimple.common.exception.EntityNotFoundException;
import edu.prlab.ecsimple.domain.Item;
import edu.prlab.ecsimple.domain.TheOrder;
import edu.prlab.ecsimple.repo.ItemRepo;
import edu.prlab.ecsimple.repo.OrderRepo;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Optional;

@Service
@RequiredArgsConstructor
@Transactional
public class OrderServiceImpl implements OrderService {

    private final OrderRepo orderRepo;
    private final ItemRepo itemRepo;

    @Override
    public Optional<TheOrder> create(TheOrder theOrder) {
        return Optional.of(theOrder)
                .map(it -> orderRepo.save(theOrder));
    }

    @Override
    public Optional<Item> create(Item item) {
        return Optional.of(item)
                .map(it -> itemRepo.save(item));
    }

    @Override
    public void addItemToOrder(Integer orderId, Integer itemId) {
        orderRepo.findById(orderId)
                .map(order -> itemRepo.findById(itemId)
                        .map(item -> order.getItems().add(item))
                        .orElseThrow(() -> new EntityNotFoundException("No found this order")))
                .orElseThrow(() -> new EntityNotFoundException("No found this order"));
    }


}
